pywurfl.algorithms

Package pywurfl :: Package algorithms |
[hide private]
[frames] | no frames]

# Package algorithms

source code

pywurfl search algorithms

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2006-2011, Armand Lynch

License: LGPL

Submodules | [hide private]
pywurfl.algorithms.wurfl pywurfl.algorithms.wurfl.handlers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.normalizers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.strategies: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.utils: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.

Classes | [hide private]
| Algorithm Base class for all pywurfl search algorithms
| JaroWinkler Jaro-Winkler Search Algorithm
| LevenshteinDistance Levenshtein distance Search Algorithm
| Tokenizer Tokenizer Search Algorithm
| TwoStepAnalysis WURFL Two Step Analysis algorithm based on the Java API implementation

Variables | [hide private]
| __doc__ = ``...``
| __url__ = ``'``http://celljam.net/``'``
| __package__ = ``'``pywurfl.algorithms``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      pywurfl search algorithms
      """